==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/DeploymentDetailsFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DeploymentDetailsFluent<A extends io.fabric8.openshift.api.model.DeploymentDetailsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item);
  public A setToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item);
  public A addToCauses(io.fabric8.openshift.api.model.DeploymentCause... items);
  public A addAllToCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items);
  public A removeFromCauses(io.fabric8.openshift.api.model.DeploymentCause... items);
  public A removeAllFromCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items);
  public A removeMatchingFromCauses(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCauses instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> getCauses();
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> buildCauses();
  public io.fabric8.openshift.api.model.DeploymentCause buildCause(java.lang.Integer index);
  public io.fabric8.openshift.api.model.DeploymentCause buildFirstCause();
  public io.fabric8.openshift.api.model.DeploymentCause buildLastCause();
  public io.fabric8.openshift.api.model.DeploymentCause buildMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  public java.lang.Boolean hasMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  public A withCauses(java.util.List<io.fabric8.openshift.api.model.DeploymentCause> causes);
  public A withCauses(io.fabric8.openshift.api.model.DeploymentCause... causes);
  public java.lang.Boolean hasCauses();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCause();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCauseLike(io.fabric8.openshift.api.model.DeploymentCause item);
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> setNewCauseLike(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item);
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editCause(java.lang.Integer index);
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editFirstCause();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editLastCause();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public interface CausesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.DeploymentCauseFluent<io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<N>>{
    public N and();
    public N endCause();
    
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/DeploymentDetailsFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DeploymentDetailsFluent<A extends io.fabric8.openshift.api.model.DeploymentDetailsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item);
  public A setToCauses(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item);
  public A addToCauses(io.fabric8.openshift.api.model.DeploymentCause... items);
  public A addAllToCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items);
  public A removeFromCauses(io.fabric8.openshift.api.model.DeploymentCause... items);
  public A removeAllFromCauses(java.util.Collection<io.fabric8.openshift.api.model.DeploymentCause> items);
  public A removeMatchingFromCauses(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildCauses instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> getCauses();
  public java.util.List<io.fabric8.openshift.api.model.DeploymentCause> buildCauses();
  public io.fabric8.openshift.api.model.DeploymentCause buildCause(java.lang.Integer index);
  public io.fabric8.openshift.api.model.DeploymentCause buildFirstCause();
  public io.fabric8.openshift.api.model.DeploymentCause buildLastCause();
  public io.fabric8.openshift.api.model.DeploymentCause buildMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  public java.lang.Boolean hasMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  public A withCauses(java.util.List<io.fabric8.openshift.api.model.DeploymentCause> causes);
  public A withCauses(io.fabric8.openshift.api.model.DeploymentCause... causes);
  public java.lang.Boolean hasCauses();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCause();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> addNewCauseLike(io.fabric8.openshift.api.model.DeploymentCause item);
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> setNewCauseLike(java.lang.Integer index,io.fabric8.openshift.api.model.DeploymentCause item);
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editCause(java.lang.Integer index);
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editFirstCause();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editLastCause();
  public io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<A> editMatchingCause(java.util.function.Predicate<io.fabric8.openshift.api.model.DeploymentCauseBuilder> predicate);
  public java.lang.String getMessage();
  public A withMessage(java.lang.String message);
  public java.lang.Boolean hasMessage();
  
  /**
   * Method is deprecated. use withMessage instead.
   */
  @java.lang.Deprecated
  public A withNewMessage(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CausesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.DeploymentCauseFluent<io.fabric8.openshift.api.model.DeploymentDetailsFluent.CausesNested<N>>{
    public N and();
    public N endCause();
    
  }
  
}
